---
title: Commands
menu:
    main:
        parent: payloads
        weight: 1
description: Commands are messages sent to the gateway.
---

# Commands

Commands are generated by [LoRa Server](/loraserver/) or external applications
integrating with the LoRa Gateway Bridge. Depending the `marshaler` configuration
these must be sent as JSON or [Protobuf](https://developers.google.com/protocol-buffers/).
For the Protobuf definitions, please refer to [gw.proto](https://github.com/brocaar/loraserver/blob/master/api/gw/gw.proto).

* The Protocol Buffers [JSON Mapping](https://developers.google.com/protocol-buffers/docs/proto3#json)
  defines that bytes must be encoded as base64 strings. This also affects the `gatewayID` field.
  When re-encoding this filed to HEX encoding, you will find the expected gateway ID string.

## `down` - downlink transmission

Request the gateway to schedule a downlink transmission.

The `context` key must contain the same value as the related uplink frame.
It holds the gateway internal context (e.g. internal timing information).

### JSON

#### Delay timing (e.g. Class-A)

{{<highlight json>}}
{
    "phyPayload": "IHN792Ld0vEHetyVv9+llJnnmz88Up6pFz8UiUdJMnUc",
    "txInfo": {
        "gatewayID": "AQIDBAUGBwg=",
        "frequency": 868100000,
        "power": 14,
        "modulation": "LORA",
        "loRaModulationInfo": {
            "bandwidth": 125,
            "spreadingFactor": 10,
            "codeRate": "4/5",
            "polarizationInversion": true
        },
        "board": 0,
        "antenna": 0,
        "timing": "DELAY",
        "delayTimingInfo": {
            "delay": "1s"
        },
        "context": "AAAAAAAAAAMAAAAAAAAABA=="
    },
    "token": 1234
}
{{</highlight>}}

#### GPS timing (e.g. Class-B)

{{<highlight json>}}
{
    "phyPayload": "IHN792Ld0vEHetyVv9+llJnnmz88Up6pFz8UiUdJMnUc",
    "txInfo": {
        "gatewayID": "AQIDBAUGBwg=",
        "frequency": 868100000,
        "power": 14,
        "modulation": "LORA",
        "loRaModulationInfo": {
            "bandwidth": 125,
            "spreadingFactor": 10,
            "codeRate": "4/5",
            "polarizationInversion": true
        },
        "board": 0,
        "antenna": 0,
        "timing": "GPS_EPOCH",
        "gpsEpochTimingInfo": {
            "timeSinceGPSEpoch": "1s"
        }
    },
    "token": 1234
}
{{</highlight>}}

#### Immediately (e.g. Class-C)

{{<highlight json>}}
{
    "phyPayload": "IHN792Ld0vEHetyVv9+llJnnmz88Up6pFz8UiUdJMnUc",
    "txInfo": {
        "gatewayID": "AQIDBAUGBwg=",
        "frequency": 868100000,
        "power": 14,
        "modulation": "LORA",
        "loRaModulationInfo": {
            "bandwidth": 125,
            "spreadingFactor": 10,
            "codeRate": "4/5",
            "polarizationInversion": true
        },
        "board": 0,
        "antenna": 0,
        "timing": "IMMEDIATELY"
    },
    "token": 1234
}
{{</highlight>}}

### Protobuf

This message is defined by the `DownlinkFrame` Protobuf message.

